aboutsummaryrefslogtreecommitdiff
path: root/vagrant/bootstrap.sh
diff options
context:
space:
mode:
authorCédric Bonhomme <cedric@cedricbonhomme.org>2015-11-26 18:47:10 +0100
committerCédric Bonhomme <cedric@cedricbonhomme.org>2015-11-26 18:47:10 +0100
commitd8d46c33dc766b904124eaad2dee5d7964711060 (patch)
treef549b7cd3acfa99425d4c7248e8b431de695bc7f /vagrant/bootstrap.sh
parentBug fix in the crawler when logging the creation of articles. (diff)
downloadnewspipe-d8d46c33dc766b904124eaad2dee5d7964711060.tar.gz
newspipe-d8d46c33dc766b904124eaad2dee5d7964711060.tar.bz2
newspipe-d8d46c33dc766b904124eaad2dee5d7964711060.zip
More refactorization.
Diffstat (limited to 'vagrant/bootstrap.sh')
-rw-r--r--vagrant/bootstrap.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/vagrant/bootstrap.sh b/vagrant/bootstrap.sh
index 76c20d44..c37acb2e 100644
--- a/vagrant/bootstrap.sh
+++ b/vagrant/bootstrap.sh
@@ -4,8 +4,8 @@ apt-get update
apt-get upgrade
apt-get install -y python3 python3-dev libpq-dev python3-pip build-essential git
-# Clone the source code of pyAggr3g470r
-git clone https://bitbucket.org/cedricbonhomme/pyaggr3g470r.git
+# Clone the source code of JARR
+git clone https://github.com/JARR-aggregator/JARR.git
if [ $? -ne 0 ]; then
echo "\nERROR: unable to clone the git repository\n"
exit 1;
@@ -15,7 +15,7 @@ fi
apt-get install -y postgresql postgresql-server-dev-9.4 postgresql-client
# Install all Python requierements
-cd pyaggr3g470r
+cd JARR
# For lxml
apt-get install -y libxml2-dev libxslt1-dev
# installation with pip
@@ -33,14 +33,14 @@ echo "ALTER USER vagrant WITH ENCRYPTED PASSWORD 'xxYzToW42';" | sudo -u postgre
echo "GRANT ALL PRIVILEGES ON DATABASE aggregator TO vagrant;" | sudo -u postgres psql
# Initializes the database
-cd pyaggr3g470r
+cd JARR
chown -R vagrant:vagrant .
sudo -u vagrant python3 manager.py db_empty
sudo -u vagrant python3 manager.py db_create
# start pyAggr3g470r at startup
echo "#!/bin/sh -e" > /etc/rc.local
-echo "cd /home/vagrant/pyaggr3g470r/" >> /etc/rc.local
+echo "cd /home/vagrant/JARR/" >> /etc/rc.local
echo "sudo -u vagrant python3 runserver.py &" >> /etc/rc.local
echo "exit 0" >> /etc/rc.local
chmod 755 /etc/rc.local
@@ -52,7 +52,7 @@ chmod 755 /etc/rc.local
#write out current crontab
sudo -u vagrant crontab -l > mycron
#echo new cron into cron file
-sudo -u vagrant echo "*/30 * * * * cd /home/vagrant/pyaggr3g470r/ ; python3 manager.py fetch_asyncio None None" >> mycron
+sudo -u vagrant echo "*/30 * * * * cd /home/vagrant/JARR/ ; python3 manager.py fetch_asyncio None None" >> mycron
#install new cron file
sudo -u vagrant crontab mycron
sudo -u vagrant rm mycron
bgstack15